%define anolis_release 3

# Remove underspecified dependencies
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^perl\\((Clone|Exporter|HTTP::Date|URI)\\)$
%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}^perl\\(HTTP::Headers\\)$
# Remove private modules and unused dependencies
%global __requires_exclude %{__requires_exclude}|^perl\\((Secret|Time::Local)\\)
%global __provides_exclude %{__provides_exclude}|^perl\\(Secret\\)$

Name:           perl-HTTP-Message
Version:        6.44
Release:        %{anolis_release}%{?dist}
Summary:        HTTP style message
License:        (GPL-1.0-or-later OR Artistic-1.0-Perl) AND CC0-1.0
URL:            https://metacpan.org/release/HTTP-Message
Source0:        https://cpan.metacpan.org/authors/id/O/OA/OALDERS/HTTP-Message-%{version}.tar.gz
BuildRequires:  make
BuildRequires:  coreutils
BuildRequires:  perl(Config)
BuildRequires:  perl(strict)
BuildRequires:  perl(warnings)
BuildRequires:  perl-generators
BuildRequires:  perl-interpreter
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.76
# Run-time:
BuildRequires:  perl(Carp)
BuildRequires:  perl(Clone)
BuildRequires:  perl(parent)
BuildRequires:  perl(IO::HTML)
BuildRequires:  perl(File::Spec)
BuildRequires:  perl(URI) >= 1.10
BuildRequires:  perl(Encode) >= 3.01
BuildRequires:  perl(HTTP::Date) >= 6
BuildRequires:  perl(Exporter) >= 5.57
BuildRequires:  perl(MIME::QuotedPrint)
BuildRequires:  perl(IO::Compress::Gzip)
BuildRequires:  perl(Compress::Raw::Zlib)
BuildRequires:  perl(Encode::Locale) >= 1
BuildRequires:  perl(MIME::Base64) >= 2.1
BuildRequires:  perl(IO::Compress::Brotli)
BuildRequires:  perl(LWP::MediaTypes) >= 6
BuildRequires:  perl(IO::Compress::Deflate)
BuildRequires:  perl(IO::Uncompress::Inflate)
BuildRequires:  perl(IO::Uncompress::RawInflate)
BuildRequires:  perl(IO::Compress::Bzip2) >= 2.021
# Tests only:
BuildRequires:  perl(lib)
BuildRequires:  perl(overload)
BuildRequires:  perl(File::Temp)
BuildRequires:  perl(Test::Needs)
BuildRequires:  perl(PerlIO::encoding)
BuildRequires:  perl(Test::More) >= 0.88
# Time::Local only used on MacOS
BuildRequires:  perl(Try::Tiny)
BuildRequires:  perl(URI::URL)
BuildArch:      noarch
Requires:       perl(IO::HTML)
Requires:       perl(URI) >= 1.10
Requires:       perl(Clone) => 0.46
Requires:       perl(Encode) >= 3.01
Conflicts:      perl-libwww-perl < 6
Requires:       perl(HTTP::Date) >= 6
Requires:       perl(MIME::QuotedPrint)
Requires:       perl(IO::Compress::Gzip)
Requires:       perl(Encode::Locale) >= 1
Requires:       perl(MIME::Base64) >= 2.1
Recommends:     perl(IO::Compress::Brotli)
Requires:       perl(LWP::MediaTypes) >= 6
Requires:       perl(IO::Compress::Deflate)
Requires:       perl(IO::Uncompress::Inflate)
Requires:       perl(IO::Uncompress::RawInflate)
Requires:       perl(Compress::Raw::Zlib) >= 2.062
Requires:       perl(IO::Compress::Bzip2) >= 2.021

%description
Perl-HTTP-Message is a Perl module that provides a set of tools
for working with HTTP messages, including requests and responses.
The module allows developers to create, parse, and manipulate
HTTP messages as objects, making it easier to work with the various
components of the message, such as headers, cookies, and content.

One of the key benefits of Perl-HTTP-Message is its flexibility.
The module provides a wide range of methods for working with HTTP
messages, allowing developers to customize their approach to suit
their specific needs. For example, developers can use the module to
set headers, retrieve cookies, and manipulate message content using
a variety of different methods.

Another important feature of Perl-HTTP-Message is its versatility. The
module can be used for a wide range of applications, from building web
applications and APIs to testing frameworks and automation tools.
Additionally, the module is well-suited for use in a variety of different
programming environments, making it a popular choice among Perl developers.

Overall, Perl-HTTP-Message is a powerful and flexible library that provides
a robust set of tools for working with HTTP messages. Its versatility and
ease of use make it an ideal choice for developers working with web
applications and APIs.

%package tests
Summary:        Tests for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       perl-Test-Harness
Requires:       perl(URI::URL)

%description tests
Tests from %{name}. Execute them with "%{_libexecdir}/%{name}/test".

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%setup -q -n HTTP-Message-%{version}
# Help generators to recognize Perl scripts
for F in t/*.t; do
    perl -i -MConfig -ple 'print $Config{startperl} if $. == 1 && !s{\A#!\s*perl}{$Config{startperl}}' "$F"
    chmod +x "$F"
done

%build
perl Makefile.PL INSTALLDIRS=vendor NO_PACKLIST=1 NO_PERLLOCAL=1
%{make_build}

%install
%{make_install}
# Install tests
mkdir -p %{buildroot}%{_libexecdir}/%{name}
cp -a t %{buildroot}%{_libexecdir}/%{name}
cat > %{buildroot}%{_libexecdir}/%{name}/test << 'EOF'
#!/bin/sh
cd %{_libexecdir}/%{name} && exec prove -I . -j "$(getconf _NPROCESSORS_ONLN)"
EOF
chmod +x %{buildroot}%{_libexecdir}/%{name}/test
%{_fixperms} %{buildroot}/*

%check
export HARNESS_OPTIONS=j$(perl -e 'if ($ARGV[0] =~ /.*-j([0-9][0-9]*).*/) {print $1} else {print 1}' -- '%{?_smp_mflags}')
make test

%files
%license LICENSE
%{perl_vendorlib}/*
%{_mandir}/man3/*

%files tests
%{_libexecdir}/%{name}

%files doc
%doc Changes CONTRIBUTING.md README.md

%changelog
* Wed Apr 12 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 6.44-3
- Optimize the spec

* Fri Feb 3 2023 Funda Wang <fundawang@yeah.net> - 6.44-2
- Add support for perl(IO::Compress::Brotli)

* Thu Feb 02 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 6.44-1
- init from upstream
